@@ -28,7 +28,7 @@
  *
  * @package Extbase
  * @subpackage Reflection
- * @version $Id: Service.php 1624 2009-11-07 14:04:29Z jocrau $
+ * @version $Id: Service.php 1789 2010-01-18 21:31:59Z jocrau $
  * @api
  */
 class Tx_Extbase_Reflection_Service implements t3lib_Singleton {
@@ -354,8 +354,8 @@ class Tx_Extbase_Reflection_Service implements t3lib_Singleton {
 				}
 			}
 
-			foreach ($method->getParameters() as $parameter) {
-				$this->methodParameters[$className][$methodName][$parameter->getName()] = $this->convertParameterReflectionToArray($parameter, $method);
+			foreach ($method->getParameters() as $parameterPosition => $parameter) {
+				$this->methodParameters[$className][$methodName][$parameter->getName()] = $this->convertParameterReflectionToArray($parameter, $parameterPosition, $method);
 			}
 		}
 		ksort($this->reflectedClassNames);
