@@ -29,7 +29,7 @@
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
 /*
- * TYPO3 SVN ID: $Id: htmlarea-gecko.js 7020 2010-02-23 14:34:10Z stan $
+ * TYPO3 SVN ID: $Id: htmlarea-gecko.js 8912 2010-09-28 06:07:06Z stan $
  */
 
 /***************************************************
@@ -379,15 +379,20 @@ HTMLArea.prototype.getBookmarkNode = function(bookmark, endPoint) {
 HTMLArea.prototype.moveToBookmark = function (bookmark) {
 	var startSpan  = this.getBookmarkNode(bookmark, true);
 	var endSpan    = this.getBookmarkNode(bookmark, false);
-
+	var parent;
 	var range = this._createRange();
-		// If the previous sibling is a text node, let the anchorNode have it as parent
-	if (startSpan.previousSibling && startSpan.previousSibling.nodeType == 3) {
-		range.setStart(startSpan.previousSibling, startSpan.previousSibling.data.length);
+	if (startSpan) {
+			// If the previous sibling is a text node, let the anchorNode have it as parent
+		if (startSpan.previousSibling && startSpan.previousSibling.nodeType == 3) {
+			range.setStart(startSpan.previousSibling, startSpan.previousSibling.data.length);
+		} else {
+			range.setStartBefore(startSpan);
+		}
+		HTMLArea.removeFromParent(startSpan);
 	} else {
-		range.setStartBefore(startSpan);
+			// For some reason, the startSpan was removed or its id attribute was removed so that it cannot be retrieved
+		range.setStart(this._doc.body, 0);
 	}
-	HTMLArea.removeFromParent(startSpan);
 		// If the bookmarked range was collapsed, the end span will not be available
 	if (endSpan) {
 			// If the next sibling is a text node, let the focusNode have it as parent
@@ -622,48 +627,95 @@ HTMLArea.prototype._checkInsertP = function() {
 	}
 	this.emptySelection(sel);
 	if (!block || /^(td|div)$/i.test(block.nodeName)) {
-		if (!block) var block = doc.body;
+		if (!block) {
+			block = doc.body;
+		}
 		if (block.hasChildNodes()) {
 			rangeClone = range.cloneRange();
-			rangeClone.setStartBefore(block.firstChild);
-				// Working around Opera issue: The following gives a range exception
-				// rangeClone.surroundContents(left = doc.createElement("p"));
-			left = doc.createElement("p");
+			if (range.startContainer == block) {
+					// Selection is directly under the block
+				var blockOnLeft = null;
+				var leftSibling = null;
+					// Looking for the farthest node on the left that is not a block
+				for (var i = range.startOffset; --i >= 0;) {
+					if (HTMLArea.isBlockElement(block.childNodes[i])) {
+						blockOnLeft = block.childNodes[i];
+						break;
+					} else {
+						rangeClone.setStartBefore(block.childNodes[i]);
+					}
+				}
+			} else {
+					// Looking for inline or text container immediate child of block
+				var inlineContainer = range.startContainer;
+				while (inlineContainer.parentNode != block) {
+					inlineContainer = inlineContainer.parentNode;
+				}
+					// Looking for the farthest node on the left that is not a block
+				var leftSibling = inlineContainer;
+				while (leftSibling.previousSibling && !HTMLArea.isBlockElement(leftSibling.previousSibling)) {
+					leftSibling = leftSibling.previousSibling;
+				}
+				rangeClone.setStartBefore(leftSibling);
+				var blockOnLeft = leftSibling.previousSibling;
+			}
+				// Avoiding surroundContents buggy in Opera and Safari
+			left = doc.createElement('p');
 			left.appendChild(rangeClone.extractContents());
-			if (!left.textContent && !left.getElementsByTagName("img") && !left.getElementsByTagName("table")) {
-				left.innerHTML = "<br />";
+			if (!left.textContent && !left.getElementsByTagName('img').length && !left.getElementsByTagName('table').length) {
+				left.innerHTML = '<br />';
 			}
 			if (block.hasChildNodes()) {
-				left = block.insertBefore(left, block.firstChild);
+				if (blockOnLeft) {
+					left = block.insertBefore(left, blockOnLeft.nextSibling);
+				} else {
+					left = block.insertBefore(left, block.firstChild);
+				}
 			} else {
 				left = block.appendChild(left);
 			}
-			left.normalize();
-			range.setEndAfter(block.lastChild);
-			range.setStartAfter(left);
-				// Working around Safari issue: The following gives a range exception
-				// range.surroundContents(right = doc.createElement("p"));
-			right = doc.createElement("p");
-			right.appendChild(range.extractContents());
-			if (!right.textContent && !left.getElementsByTagName("img") && !left.getElementsByTagName("table")) {
-				right.innerHTML = "<br />";
+			block.normalize();
+				// Looking for the farthest node on the right that is not a block
+			var rightSibling = left;
+			while (rightSibling.nextSibling && !HTMLArea.isBlockElement(rightSibling.nextSibling)) {
+				rightSibling = rightSibling.nextSibling;
 			}
-			block.appendChild(right);
-			right.normalize();
+			var blockOnRight = rightSibling.nextSibling;
+			range.setEndAfter(rightSibling);
+			range.setStartAfter(left);
+				// Avoiding surroundContents buggy in Opera and Safari
+			right = doc.createElement('p');
+			right.appendChild(range.extractContents());
+			if (!right.textContent && !right.getElementsByTagName('img').length && !right.getElementsByTagName('table').length) {
+				right.innerHTML = '<br />';
+			}
+			if (!(left.childNodes.length == 1 && right.childNodes.length == 1 && left.firstChild.nodeName.toLowerCase() == 'br' && right.firstChild.nodeName.toLowerCase() == 'br')) {
+				if (blockOnRight) {
+					right = block.insertBefore(right, blockOnRight);
+				} else {
+					right = block.appendChild(right);
+				}
+				this.selectNodeContents(right, true);
+			} else {
+				this.selectNodeContents(left, true);
+			}
+			block.normalize();
 		} else {
 			var first = block.firstChild;
-			if (first) block.removeChild(first);
+			if (first) {
+				block.removeChild(first);
+			}
 			right = doc.createElement("p");
 			if (HTMLArea.is_safari || HTMLArea.is_opera) {
 				right.innerHTML = "<br />";
 			}
 			right = block.appendChild(right);
+			this.selectNodeContents(right, true);
 		}
-		this.selectNodeContents(right, true);
 	} else {
 		range.setEndAfter(block);
 		var df = range.extractContents(), left_empty = false;
-		if (!/\S/.test(block.innerHTML)) {
+		if (!/\S/.test(block.innerHTML) || (!/\S/.test(block.textContent) && !/<(img|hr|table)/i.test(block.innerHTML))) {
 			if (!HTMLArea.is_opera) {
 				block.innerHTML = "<br />";
 			}
@@ -671,7 +723,7 @@ HTMLArea.prototype._checkInsertP = function() {
 		}
 		p = df.firstChild;
 		if (p) {
-			if (!/\S/.test(p.textContent)) {
+			if (!/\S/.test(p.innerHTML) || (!/\S/.test(p.textContent) && !/<(img|hr|table)/i.test(p.innerHTML))) {
  				if (/^h[1-6]$/i.test(p.nodeName)) {
 					p = this.convertNode(p, "p");
 				}
@@ -681,7 +733,7 @@ HTMLArea.prototype._checkInsertP = function() {
 				if (!HTMLArea.is_opera) {
 					p.innerHTML = "<br />";
 				}
-				if(/^li$/i.test(p.nodeName) && left_empty && !block.nextSibling) {
+				if (/^li$/i.test(p.nodeName) && left_empty && (!block.nextSibling || !/^li$/i.test(block.nextSibling.nodeName))) {
 					left = block.parentNode;
 					left.removeChild(block);
 					range.setEndAfter(left);
@@ -690,22 +742,26 @@ HTMLArea.prototype._checkInsertP = function() {
 				}
 			}
 			range.insertNode(df);
-				// Remove any anchor created empty
+				// Remove any anchor created empty on both sides of the selection
 			if (p.previousSibling) {
 				var a = p.previousSibling.lastChild;
 				if (a && /^a$/i.test(a.nodeName) && !/\S/.test(a.innerHTML)) {
-					if (HTMLArea.is_opera) {
-						this.removeMarkup(a);
-					} else {
-						HTMLArea.removeFromParent(a);
-					}
-				}
-				if (!/\S/.test(p.previousSibling.textContent) && !HTMLArea.is_opera) {
-					p.previousSibling.innerHTML = "<br />";
+					this.convertNode(a, 'br');
 				}
 			}
+			var a = p.lastChild;
+			if (a && /^a$/i.test(a.nodeName) && !/\S/.test(a.innerHTML)) {
+				this.convertNode(a, 'br');
+			}
+				// Walk inside the deepest child element (presumably inline element)
+			while (p.firstChild && p.firstChild.nodeType == 1 && !/^(br|img|hr|table)$/i.test(p.firstChild.nodeName)) {
+				p = p.firstChild;
+			}
 			if (/^br$/i.test(p.nodeName)) {
-				p = p.parentNode.insertBefore(this._doc.createTextNode("\x20"), p);
+				p = p.parentNode.insertBefore(doc.createTextNode('\x20'), p);
+			} else if (!/\S/.test(p.innerHTML)) {
+					// Need some element inside the deepest element
+				p.appendChild(doc.createElement('br'));
 			}
 			this.selectNodeContents(p, true);
 		} else {
