@@ -27,7 +27,7 @@
 /**
  * [CLASS/FUNCTION INDEX of SCRIPT]
  *
- * $Id: class.tx_tstemplateobjbrowser.php 6991 2010-02-23 10:04:55Z ohader $
+ * $Id: class.tx_tstemplateobjbrowser.php 8170 2010-07-13 14:51:44Z steffenk $
  */
 
 $GLOBALS['LANG']->includeLLFile('EXT:tstemplate_objbrowser/locallang.xml');
@@ -467,7 +467,14 @@ class tx_tstemplateobjbrowser extends t3lib_extobjbase {
 					$errMsg[]=($inf[1]).": &nbsp; &nbsp;".$inf[0];
 				}
 				$theOutput .= $this->pObj->doc->spacer(10);
-				$theOutput .= $this->pObj->doc->section($GLOBALS['TBE_TEMPLATE']->rfw($GLOBALS['LANG']->getLL('errorsWarnings')), implode($errMsg, "<br />"), 0, 1, 0, 1);
+
+				$flashMessage = t3lib_div::makeInstance(
+						't3lib_FlashMessage',
+						implode($errMsg, '<br />'),
+						$GLOBALS['LANG']->getLL('errorsWarnings'),
+						t3lib_FlashMessage::ERROR
+					);
+				$theOutput .= $flashMessage->render();
 			}
 
 
