@@ -27,7 +27,7 @@
 /**
  * Wizard for inserting TSconfig in form fields. (page,user or TS)
  *
- * $Id: wizard_tsconfig.php 5526 2009-06-02 13:52:04Z benni $
+ * $Id: wizard_tsconfig.php 8401 2010-07-28 09:12:31Z ohader $
  * Revised for TYPO3 3.6 November/2003 by Kasper Skaarhoj
  * XHTML compliant
  *
@@ -156,7 +156,9 @@ class SC_wizard_tsconfig {
 		$this->objString = t3lib_div::_GP('objString');
 		$this->onlyProperty = t3lib_div::_GP('onlyProperty');
 			// Preparing some JavaScript code:
-		if (!is_array($this->P['fieldChangeFunc']))	$this->P['fieldChangeFunc']=array();
+		if (!$this->areFieldChangeFunctionsValid()) {
+			$this->P['fieldChangeFunc']=array();
+		}
 		unset($this->P['fieldChangeFunc']['alert']);
 		$update='';
 		foreach($this->P['fieldChangeFunc'] as $k=>$v)	{
@@ -628,6 +630,19 @@ class SC_wizard_tsconfig {
 			// Return link:
 		return $out;
 	}
+
+	/**
+	 * Determines whether submitted field change functions are valid
+	 * and are coming from the system and not from an external abuse.
+	 *
+	 * @return boolean Whether the submitted field change functions are valid
+	 */
+	protected function areFieldChangeFunctionsValid() {
+		return (
+			isset($this->P['fieldChangeFunc']) && is_array($this->P['fieldChangeFunc']) && isset($this->P['fieldChangeFuncHash'])
+			&& $this->P['fieldChangeFuncHash'] == t3lib_div::hmac(serialize($this->P['fieldChangeFunc']))
+		);
+	}
 }
 
 
